#!/bin/bash -l
#SBATCH --job-name=cDFT_TEST
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=48
#SBATCH --mem-per-cpu=3700
#SBATCH --time=01:00:00

module purge ; module load GCC/9.3.0 OpenMPI/4.0.3 ScaLAPACK/2.1.0 CMake/3.16.4 OpenBLAS/0.3.9 FFTW/3.3.8 ELPA/2019.11.001

export cp2k="/home/chem/mssnkt/CODES/CP2K/cp2k-7.1/exe/local/cp2k.popt"

export OMP_NUM_THREADS=1
unset I_MPI_PMI_LIBRARY

# DFT energy of the dimer
mpirun -np ${SLURM_NTASKS} $cp2k -i dimer_pbe.inp -o dimer_pbe.out

# DFT energy of fragment A (and cube file!)
mpirun -np ${SLURM_NTASKS} $cp2k -i fragment_A.inp -o water-dimer-frag-a-pbe-energy.out

# DFT energy of fragment B (and cube file!)
mpirun -np ${SLURM_NTASKS} $cp2k -i fragment_B.inp -o water-dimer-frag-b-pbe-energy.out

# cDFT energy of the dimer
mpirun -np ${SLURM_NTASKS} $cp2k -i dimer_pbe_cdft.inp -o water-dimer-cdft-frag-adj.out

# According to Eq. (6) in Phys. Chem. Chem. Phys., 2017, 19, 791--803,
# the charge transfer energy \Delta E^{CT} can be defined as:
# \Delta E^{CT} = \Delta E^{DFT} - \Delta E^{cDFT}

e_dft=`grep ENERGY dimer_pbe.out | tail -1 | awk '{print $9}'`
e_Cdft=`grep ENERGY water-dimer-cdft-frag-adj.out | tail -1 | awk '{print $9}'`
e_ct=`echo "($e_dft-($e_Cdft))*(-1000)" |bc -l`
echo $e_ct, "mHa"

